==> aroundme_0_5_3.zip: aroundme_0_5_3/aroundme/language/1/barnraiser_01/node_acs.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'node_common.lang.php');
/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/

//HEADER
$lang['hdr_acs_permissions'] = 					"access control system node permissions";


//SUBMIT
$lang['sub_update_permissions'] = 				"update permissions";


//BODY TEXT
$lang['txt_acs_permissions_help'] =				"Below is a table showing all resource privileges and roles available. Check each box that you wish to grant a permission to, then press 'update permissions'";
$lang['txt_acs_role_number'] =					"role number";

?>

==> aroundme_0_6_4.zip: aroundme_0_6_4/aroundme/language/1/barnraiser_01/node_acs.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'common.lang.php');


//HEADERS
$lang['hdr_menu'] = 							"menu";
$lang['hdr_acs_permissions'] = 					"access control system node permissions";


//SUBMIT
$lang['sub_update_permissions'] = 				"update permissions";


//BODY TEXT
$lang['txt_acs_permissions_help'] =				"<font color='red'>Note: a visitor is a person who is <b>NOT</b> logged in. We advice that you do not give them permissions to add, edit, tag or comment any item or access the adminstration area.</font><p>Below is a table showing all resource privileges and roles available. Check each box that you wish to grant a permission to, then press 'update permissions'.</p>";
$lang['txt_acs_role_number'] =					"role number";

?>
